#
# spec file for package ghc-http-types
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http-types
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.12.3
Release:        5.8
Summary:        Generic HTTP types for Haskell (for both client and server code)
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-quickcheck-instances-devel
%endif

%description
Generic HTTP types for Haskell (for both client and server code).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG README

%changelog
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Mon Feb 25 2019 psimons@suse.com
- Update http-types to version 0.12.3.
  * 0.12.3 [2019-02-24]
  Remove now-invalid doctest options from doctests.hs.
* Wed Oct 10 2018 psimons@suse.com
- Update http-types to version 0.12.2.
  * 0.12.2 [2018-09-26]
  Add new parseQueryReplacePlus function, which allows specifying whether to replace '+' with ' '.
  Add header name constants for "Prefer" and "Preference-Applied" (RFC 7240).
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update http-types to version 0.12.1.
  * Add new functions for constructing a query URI where not all parts are escaped.
  * URI encoding is now back to upper-case hexadecimal, as that is the preferred canonicalization, and the previous change caused issues with URI
  * signing in at least amazonka.
  * Remove dependency on blaze-builder. (Note that as a side effect of this, URI encoding is now using lower-case rather than uppercase hexadecimal.)
  * Add Bounded instance to Status.
  * Re-export more status codes and http20 from Network.HTTP.Types.
  * New status codes, new headers.
  * Fixed typo in imATeapot, added missing toEnum.
  * Oh, and http20.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.9.1 revision 0 with cabal2obs.
* Sun Jun  5 2016 mimi.vx@gmail.com
- update to 0.9.1
- remove useless _service
  * New function: parseByteRanges.
  * Support for HTTP status 422 "Unprocessable Entity" (RFC 4918).
* Wed Dec 30 2015 mimi.vx@gmail.com
- update to 0.9
* Tue Apr 21 2015 mimi.vx@gmail.com
- version bump to 0.8.6
  * no upstream changelog
* Sun Feb  1 2015 mimi.vx@gmail.com
- version bump to 0.8.5
    + should not link to aws
    + Allow array 0.5
    + remove upper boundary on text, may text simply never break anything
    + Derive some typeclasses for ByteRange
    + Allow case-insensitive 1.2
    + Add additional HTTP status codes as per RFC 6585 (close #45)
    + Add Network.HTTP.Types.URI.extractPath …
    + Add support for HTTPS URLs to extractPath
    + Add documentation and tests for extractPath
    + Add doctest driver
    + extractPath from Network.HTTP.Types
    + Added urlEncode docs
* Mon Oct  7 2013 sbahling@suse.com
- Initial package - version 0.8.1
